<?php
/**
 * X Hub Theme Customizer
 *
 * @package X Hub
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function x_hub_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	//select sanitization function
	function x_hub_sanitize_select( $input, $setting ){
		$input = sanitize_key($input);
		$choices = $setting->manager->get_control( $setting->id )->choices;
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );                
		  
	}

	$wp_customize->add_panel( 'x_hub_settings', array(
		 'priority'       => 50,
		  'title'          => __('X Hub Theme settings', 'x-hub'),
		  'description'    => __('All X Hub theme settings', 'x-hub'),
		  ) );
    $wp_customize->add_section('x_hub_header', array(
		'title' => __('X Hub Header Settings', 'x-hub'),
		'capability'     => 'edit_theme_options',
		'description'     => __('X Hub theme header settings', 'x-hub'),
		'panel'    => 'x_hub_settings',
	
	));
	$wp_customize->add_setting('x_hub_main_menu_position', array(
        'default'        => 'top',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_hub_sanitize_select',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('x_hub_main_menu_position', array(
        'label'      => __('Main Menu Position', 'x-hub'),
        'description'=> __('You can set the menu top of the page or under logo. ', 'x-hub'),
        'section'    => 'x_hub_header',
        'settings'   => 'x_hub_main_menu_position',
        'type'       => 'select',
        'choices'    => array(
            'top' => __('Top', 'x-hub'),
            'bottom' => __('Bottom', 'x-hub'),
        ),
    ));
	//xhub blog settings
    $wp_customize->add_section('x_hub_blog', array(
		'title' => __('X Hub Blog Settings', 'x-hub'),
		'capability'     => 'edit_theme_options',
		'description'     => __('X Hub theme blog settings', 'x-hub'),
		'panel'    => 'x_hub_settings',
	
	));
	$wp_customize->add_setting('x_hub_blog_container', array(
        'default'        => 'container',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_hub_sanitize_select',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('x_hub_blog_container', array(
        'label'      => __('Container type', 'x-hub'),
        'description'=> __('You can set standard container or full width container. ', 'x-hub'),
        'section'    => 'x_hub_blog',
        'settings'   => 'x_hub_blog_container',
        'type'       => 'select',
        'choices'    => array(
            'container' => __('Standard Container', 'x-hub'),
            'container-fluid' => __('Full width Container', 'x-hub'),
        ),
    ));
    $wp_customize->add_setting('x_hub_blog_layout', array(
        'default'        => 'rightside',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_hub_sanitize_select',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('x_hub_blog_layout', array(
        'label'      => __('Select Blog Layout', 'x-hub'),
        'description'=> __('Right and Left sidebar only show when sidebar widget is available. ', 'x-hub'),
        'section'    => 'x_hub_blog',
        'settings'   => 'x_hub_blog_layout',
        'type'       => 'select',
        'choices'    => array(
            'rightside' => __('Right Sidebar', 'x-hub'),
            'leftside' => __('Left Sidebar', 'x-hub'),
            'fullwidth' => __('No Sidebar', 'x-hub'),
        ),
    ));
	$wp_customize->add_setting('x_hub_blog_style', array(
        'default'        => 'list',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_hub_sanitize_select',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('x_hub_blog_style', array(
        'label'      => __('Select Blog Style', 'x-hub'),
        'section'    => 'x_hub_blog',
        'settings'   => 'x_hub_blog_style',
        'type'       => 'select',
        'choices'    => array(
            'list' => __('List Style', 'x-hub'),
            'classic' => __('Classic Style', 'x-hub'),
        ),
    ));
		//xhub page settings
		$wp_customize->add_section('x_hub_page', array(
			'title' => __('X Hub Page Settings', 'x-hub'),
			'capability'     => 'edit_theme_options',
			'description'     => __('X Hub theme blog settings', 'x-hub'),
			'panel'    => 'x_hub_settings',
		
		));
		$wp_customize->add_setting('x_hub_page_container', array(
			'default'        => 'container',
			'capability'     => 'edit_theme_options',
			'type'           => 'theme_mod',
			'sanitize_callback' => 'x_hub_sanitize_select',
			'transport' => 'refresh',
		));
		$wp_customize->add_control('x_hub_page_container', array(
			'label'      => __('Page Container type', 'x-hub'),
			'description'=> __('You can set standard container or full width container for page. ', 'x-hub'),
			'section'    => 'x_hub_page',
			'settings'   => 'x_hub_page_container',
			'type'       => 'select',
			'choices'    => array(
				'container' => __('Standard Container', 'x-hub'),
				'container-fluid' => __('Full width Container', 'x-hub'),
			),
		));	
		$wp_customize->add_setting('x_hub_page_header', array(
			'default'        => 'show',
			'capability'     => 'edit_theme_options',
			'type'           => 'theme_mod',
			'sanitize_callback' => 'x_hub_sanitize_select',
			'transport' => 'refresh',
		));
		$wp_customize->add_control('x_hub_page_header', array(
			'label'      => __('Show Page header', 'x-hub'),
			'section'    => 'x_hub_page',
			'settings'   => 'x_hub_page_header',
			'type'       => 'select',
			'choices'    => array(
				'show' => __('Show all pages', 'x-hub'),
				'hide-home' => __('Hide Only Front Page', 'x-hub'),
				'hide' => __('Hide All Pages', 'x-hub'),
			),
		));	




	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'x_hub_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'x_hub_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'x_hub_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function x_hub_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function x_hub_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function x_hub_customize_preview_js() {
	wp_enqueue_script( 'xhub-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), X_Hub_VERSION, true );
}
add_action( 'customize_preview_init', 'x_hub_customize_preview_js' );
